Package: netrics
Title: Many Ways to Measure and Classify Membership for Networks,
        Nodes, and Ties
Version: 0.2.1
Date: 2026-04-04
Description: Many tools for calculating network, node, or tie
   marks, measures, motifs and memberships of many different types of networks.
   Marks identify structural positions, measures quantify network properties,
   memberships classify nodes into groups, and motifs tabulate substructure participation.
   All functions operate with all classes of network data covered in 'manynet',
   and on directed, undirected, multiplex, multimodal, signed, and other networks.
URL: https://stocnet.github.io/netrics/
BugReports: https://github.com/stocnet/netrics/issues
License: MIT + file LICENSE
Language: en-GB
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 3.6.0), manynet
Imports: dplyr, igraph (>= 2.1.0)
Suggests: autograph, sna, testthat (>= 3.0.0)
Authors@R: 
    c(person(given = "James",
             family = "Hollway",
             role = c("cre", "aut", "ctb"),
             email = "james.hollway@graduateinstitute.ch",
             comment = c("IHEID", ORCID = "0000-0002-8361-9647"))
    )
Config/Needs/build: roxygen2, devtools
Config/Needs/check: covr, lintr, spelling
Config/Needs/website: pkgdown
Config/testthat/parallel: true
Config/testthat/edition: 3
Config/testthat/start-first: measure_net
NeedsCompilation: no
Packaged: 2026-04-04 08:25:06 UTC; hollway
Author: James Hollway [cre, aut, ctb] (IHEID, ORCID:
    <https://orcid.org/0000-0002-8361-9647>)
Maintainer: James Hollway <james.hollway@graduateinstitute.ch>
Repository: CRAN
Date/Publication: 2026-04-06 05:10:16 UTC
Built: R 4.6.0; ; 2026-04-29 21:48:38 UTC; unix
