# Generated by roxygen2: do not edit by hand

export("%>%")
export(cluster_concor)
export(cluster_cosine)
export(cluster_hierarchical)
export(k_elbow)
export(k_gap)
export(k_silhouette)
export(k_strict)
export(net_by_adhesion)
export(net_by_assortativity)
export(net_by_balance)
export(net_by_betweenness)
export(net_by_closeness)
export(net_by_cohesion)
export(net_by_components)
export(net_by_congruency)
export(net_by_connectedness)
export(net_by_core)
export(net_by_degree)
export(net_by_density)
export(net_by_diameter)
export(net_by_diversity)
export(net_by_efficiency)
export(net_by_eigenvector)
export(net_by_equivalency)
export(net_by_factions)
export(net_by_harmonic)
export(net_by_heterophily)
export(net_by_homophily)
export(net_by_immunity)
export(net_by_indegree)
export(net_by_independence)
export(net_by_infection_complete)
export(net_by_infection_peak)
export(net_by_infection_total)
export(net_by_length)
export(net_by_modularity)
export(net_by_outdegree)
export(net_by_reach)
export(net_by_reciprocity)
export(net_by_recovery)
export(net_by_reproduction)
export(net_by_richclub)
export(net_by_richness)
export(net_by_scalefree)
export(net_by_smallworld)
export(net_by_spatial)
export(net_by_strength)
export(net_by_toughness)
export(net_by_transitivity)
export(net_by_transmissibility)
export(net_by_upperbound)
export(net_by_waves)
export(net_x_brokerage)
export(net_x_change)
export(net_x_correlation)
export(net_x_dyad)
export(net_x_hazard)
export(net_x_hierarchy)
export(net_x_mixed)
export(net_x_stability)
export(net_x_tetrad)
export(net_x_triad)
export(node_by_adopt_exposure)
export(node_by_adopt_recovery)
export(node_by_adopt_threshold)
export(node_by_adopt_time)
export(node_by_alpha)
export(node_by_authority)
export(node_by_betweenness)
export(node_by_bridges)
export(node_by_brokering_activity)
export(node_by_brokering_exclusivity)
export(node_by_closeness)
export(node_by_constraint)
export(node_by_coreness)
export(node_by_deg)
export(node_by_degree)
export(node_by_distance)
export(node_by_diversity)
export(node_by_eccentricity)
export(node_by_efficiency)
export(node_by_effsize)
export(node_by_eigenvector)
export(node_by_equivalency)
export(node_by_flow)
export(node_by_harmonic)
export(node_by_heterophily)
export(node_by_hierarchy)
export(node_by_homophily)
export(node_by_hub)
export(node_by_indegree)
export(node_by_induced)
export(node_by_information)
export(node_by_kcoreness)
export(node_by_leverage)
export(node_by_multidegree)
export(node_by_neighbours_degree)
export(node_by_outdegree)
export(node_by_pagerank)
export(node_by_posneg)
export(node_by_power)
export(node_by_randomwalk)
export(node_by_reach)
export(node_by_reciprocity)
export(node_by_redundancy)
export(node_by_richness)
export(node_by_stress)
export(node_by_subgraph)
export(node_by_transitivity)
export(node_by_vitality)
export(node_in_adopter)
export(node_in_automorphic)
export(node_in_betweenness)
export(node_in_brokering)
export(node_in_community)
export(node_in_component)
export(node_in_core)
export(node_in_eigen)
export(node_in_equivalence)
export(node_in_fluid)
export(node_in_greedy)
export(node_in_infomap)
export(node_in_leiden)
export(node_in_louvain)
export(node_in_optimal)
export(node_in_partition)
export(node_in_regular)
export(node_in_roulette)
export(node_in_spinglass)
export(node_in_strong)
export(node_in_structural)
export(node_in_walktrap)
export(node_in_weak)
export(node_is_core)
export(node_is_cutpoint)
export(node_is_exposed)
export(node_is_fold)
export(node_is_independent)
export(node_is_infected)
export(node_is_isolate)
export(node_is_latent)
export(node_is_max)
export(node_is_mean)
export(node_is_mentor)
export(node_is_min)
export(node_is_neighbor)
export(node_is_pendant)
export(node_is_random)
export(node_is_recovered)
export(node_is_universal)
export(node_x_brokerage)
export(node_x_dyad)
export(node_x_exposure)
export(node_x_path)
export(node_x_tetrad)
export(node_x_tie)
export(node_x_triad)
export(tie_by_betweenness)
export(tie_by_closeness)
export(tie_by_cohesion)
export(tie_by_degree)
export(tie_by_eigenvector)
export(tie_is_bridge)
export(tie_is_cyclical)
export(tie_is_feedback)
export(tie_is_imbalanced)
export(tie_is_loop)
export(tie_is_max)
export(tie_is_min)
export(tie_is_multiple)
export(tie_is_path)
export(tie_is_random)
export(tie_is_reciprocated)
export(tie_is_simmelian)
export(tie_is_transitive)
export(tie_is_triangular)
export(tie_is_triplet)
importFrom(dplyr,"%>%")
importFrom(igraph,V)
importFrom(igraph,adhesion)
importFrom(igraph,all_shortest_paths)
importFrom(igraph,alpha_centrality)
importFrom(igraph,articulation_points)
importFrom(igraph,assortativity_degree)
importFrom(igraph,cohesion)
importFrom(igraph,components)
importFrom(igraph,decompose)
importFrom(igraph,degree)
importFrom(igraph,delete_edges)
importFrom(igraph,delete_vertices)
importFrom(igraph,diameter)
importFrom(igraph,distances)
importFrom(igraph,edge_betweenness)
importFrom(igraph,edge_density)
importFrom(igraph,feedback_arc_set)
importFrom(igraph,fit_power_law)
importFrom(igraph,graph_from_incidence_matrix)
importFrom(igraph,is_bipartite)
importFrom(igraph,ivs_size)
importFrom(igraph,knn)
importFrom(igraph,largest_ivs)
importFrom(igraph,make_ego_graph)
importFrom(igraph,mean_distance)
importFrom(igraph,power_centrality)
importFrom(igraph,reciprocity)
importFrom(igraph,transitivity)
importFrom(igraph,triad_census)
importFrom(igraph,triangles)
importFrom(igraph,vcount)
importFrom(igraph,which_loop)
importFrom(igraph,which_multiple)
importFrom(igraph,which_mutual)
importFrom(manynet,as_igraph)
importFrom(manynet,is_complex)
importFrom(manynet,is_twomode)
importFrom(manynet,is_weighted)
importFrom(manynet,tie_weights)
importFrom(stats,as.dist)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,hclust)
importFrom(stats,median)
