% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_centrality_closeness.R
\name{measure_centralities_close}
\alias{measure_centralities_close}
\alias{tie_by_closeness}
\title{Measuring ties closeness-like centrality}
\usage{
tie_by_closeness(.data, normalized = TRUE)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{normalized}{Logical scalar, whether scores are normalized.
Different denominators may be used depending on the measure,
whether the object is one-mode or two-mode, and other arguments.
By default TRUE.}
}
\value{
A \code{tie_measure} numeric vector the length of the ties in the network,
providing the scores for each tie.
If the network is labelled,
then the scores will be labelled with the ties' adjacent nodes' names.
}
\description{
\code{tie_by_closeness()} measures the closeness of each tie to other ties
in the network.

All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. \code{\link[manynet:to_undirected]{to_undirected()}} functions.
All centrality and centralization measures return normalized measures by default,
including for two-mode networks.
}
\examples{
(ec <- tie_by_closeness(ison_adolescents))
ison_adolescents |> mutate_ties(weight = ec)
}
\seealso{
Other closeness:
\code{\link{measure_central_close}},
\code{\link{measure_centralisation_close}}

Other centrality:
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralisation_between}},
\code{\link{measure_centralisation_close}},
\code{\link{measure_centralisation_degree}},
\code{\link{measure_centralisation_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}

Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}

Other tie:
\code{\link{mark_dyads}},
\code{\link{mark_select_tie}},
\code{\link{mark_ties}},
\code{\link{mark_triangles}},
\code{\link{measure_broker_tie}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}
}
\concept{centrality}
\concept{closeness}
\concept{measures}
\concept{tie}
