% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mark_ties.R
\name{mark_ties}
\alias{mark_ties}
\alias{tie_is_loop}
\alias{tie_is_feedback}
\alias{tie_is_bridge}
\alias{tie_is_path}
\title{Marking ties based on structural properties}
\usage{
tie_is_loop(.data)

tie_is_feedback(.data)

tie_is_bridge(.data)

tie_is_path(.data, from, to, all_paths = FALSE)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{from}{The index or name of the node from which the path should start.}

\item{to}{The index or name of the node to which the path should be traced.}

\item{all_paths}{Whether to return a list of paths or sample just one.
By default FALSE, sampling just a single path.}
}
\value{
A \code{tie_mark} logical vector the length of the ties in the network,
giving either TRUE or FALSE for each tie depending on
whether the condition is matched.
}
\description{
These functions return logical vectors the length of the ties
in a network identifying which hold certain properties or positions in the network.
\itemize{
\item \code{tie_is_loop()} marks ties that are loops.
\item \code{tie_is_feedback()} marks ties that are feedback arcs causing the network to not be acyclic.
\item \code{tie_is_bridge()} marks ties that cut or act as articulation points in a network.
\item \code{tie_is_path()} marks ties on a path from one node to another.
}

They are most useful in highlighting parts of the network that
are particularly well- or poorly-connected.
}
\examples{
tie_is_loop(fict_marvel)
tie_is_feedback(ison_algebra)
tie_is_bridge(ison_brandes)
ison_adolescents |>
  mutate_ties(route = tie_is_path(from = "Jane", to = 7)) 
}
\seealso{
Other marks:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_dyads}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{mark_select_tie}},
\code{\link{mark_triangles}}

Other tie:
\code{\link{mark_dyads}},
\code{\link{mark_select_tie}},
\code{\link{mark_triangles}},
\code{\link{measure_broker_tie}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}
}
\concept{marks}
\concept{tie}
