% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/member_core.R
\name{measure_core}
\alias{measure_core}
\alias{node_by_kcoreness}
\alias{node_by_coreness}
\title{Measuring nodes' coreness}
\usage{
node_by_kcoreness(.data)

node_by_coreness(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{node_measure} numeric vector the length of the nodes in the network,
providing the scores for each node.
If the network is labelled,
then the scores will be labelled with the nodes' names.
}
\description{
These functions identify nodes belonging to (some level of) the core of a network:
\itemize{
\item \code{node_by_coreness()} returns a continuous measure of how closely each node
resembles a typical core node.
\item \code{node_by_kcoreness()} assigns nodes to their level of k-coreness.
}
}
\section{k-coreness}{

k-coreness captures the maximal subgraphs in which each vertex has at least
degree \emph{k}, where \emph{k} is also the order of the subgraph.
As described in \code{igraph::coreness},
a node's coreness is \emph{k} if it belongs to the \emph{k}-core
but not to the (\emph{k}+1)-core.
}

\examples{
node_by_kcoreness(ison_adolescents)
node_by_coreness(ison_adolescents)
}
\references{
\subsection{On k-coreness}{

Seidman, Stephen B. 1983.
"Network structure and minimum degree".
\emph{Social Networks}, 5(3), 269-287.
\doi{10.1016/0378-8733(83)90028-X}

Batagelj, Vladimir, and Matjaz Zaversnik. 2003.
"An O(m) algorithm for cores decomposition of networks".
\emph{arXiv preprint} cs/0310049.
\doi{10.48550/arXiv.cs/0310049}
}
}
\seealso{
Other core-periphery:
\code{\link{mark_core}},
\code{\link{member_core}}

Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{core-periphery}
\concept{measures}
\concept{nodal}
