% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/netrics-defunct.R
\name{defunct}
\alias{defunct}
\title{Functions that have been renamed, superseded, or are no longer working}
\value{
Results as expected
along with a warning to use new function naming in the future.
}
\description{
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}}
Generally these functions have been superseded or renamed.
Upon using them, a message is provided directing the user to the new function.
However, at this stage of package development,
we generally clear older defunct functions at each minor release,
and so you are strongly encouraged to use the new functions/names/syntax
wherever possible and update your scripts accordingly.
}
\keyword{internal}
