% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_change.R
\name{motif_periods}
\alias{motif_periods}
\alias{net_x_change}
\alias{net_x_stability}
\alias{net_x_correlation}
\title{Motifs of network change}
\usage{
net_x_change(.data, object2)

net_x_stability(.data, object2)

net_x_correlation(.data, object2)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{object2}{A network object.}
}
\value{
A \code{network_motif} named numeric vector or sometimes a data frame with
one row and a column for each motif type,
giving the count of each motif in the network.
This is printed as a tibble to avoid greedy printing of long vectors.
}
\description{
These functions measure certain topological features of networks:
\itemize{
\item \code{net_x_change()} measures the Hamming distance between two or more networks.
\item \code{net_x_stability()} measures the Jaccard index of stability between two or more networks.
\item \code{net_x_correlation()} measures the product-moment correlation between two networks.
}

These \verb{net_*()} functions return a numeric vector the length of the number
of networks minus one. E.g., the periods between waves.
}
\seealso{
Other change:
\code{\link{measure_periods}}

Other motifs:
\code{\link{motif_brokerage_net}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_hazard}},
\code{\link{motif_hierarchy}},
\code{\link{motif_net}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{change}
\concept{motifs}
