% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_centrality_eigen.R
\name{measure_centralisation_eigen}
\alias{measure_centralisation_eigen}
\alias{net_by_eigenvector}
\alias{mode_by_eigenvector}
\title{Measuring networks eigenvector-like centralisation}
\usage{
net_by_eigenvector(.data, normalized = TRUE)

mode_by_eigenvector(.data, normalized = TRUE)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{normalized}{Logical scalar, whether scores are normalized.
Different denominators may be used depending on the measure,
whether the object is one-mode or two-mode, and other arguments.
By default TRUE.}
}
\value{
\code{net_by_eigenvector()} returns a \code{network_measure} scalar;
\code{mode_by_eigenvector()} returns a \code{mode_measure} numeric vector of length two,
giving one centralization score per mode.
}
\description{
\itemize{
\item \code{net_by_eigenvector()} measures the eigenvector centralization for a
network as a single score.
\item \code{mode_by_eigenvector()} measures eigenvector centralization separately for
each mode of a two-mode network (via projection to each mode), returning one
score per mode (following Borgatti and Everett, 1997).
}

All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. \code{\link[manynet:to_undirected]{to_undirected()}} functions.
All centrality and centralization measures return normalized measures
by default, including for two-mode networks.

For two-mode networks the two modes have different theoretical maxima, so
\code{net_by_eigenvector()} reports a single network-level score by applying
Freeman's general centralization index over the normalized node eigenvector
scores, whereas \code{mode_by_eigenvector()} reports the per-mode scores directly.
}
\examples{
net_by_eigenvector(ison_southern_women)
mode_by_eigenvector(ison_southern_women)
}
\references{
Borgatti, Stephen P., and Martin G. Everett. 1997.
"Network analysis of 2-mode data."
\emph{Social Networks} 19(3): 243-269.
\doi{10.1016/S0378-8733(96)00301-2}
}
\seealso{
Other eigenvector:
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_eigen}}

Other centrality:
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralisation_between}},
\code{\link{measure_centralisation_close}},
\code{\link{measure_centralisation_degree}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}
}
\concept{centrality}
\concept{eigenvector}
