% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/member_core.R
\name{member_core}
\alias{member_core}
\alias{node_in_core}
\title{Memberships in core-periphery categories}
\usage{
node_in_core(.data, groups = 3, cluster_by = c("bins", "quantiles", "kmeans"))
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{groups}{Number of categories to create. Must be at least 2 and at most
the number of nodes in the network. Default is 3.}

\item{cluster_by}{Method to use to create the categories.
One of "bins" (equal-width bins), "quantiles" (quantile-based bins),
or "kmeans" (k-means clustering). Default is "bins".}
}
\value{
A \code{node_member} character vector the length of the nodes in the network,
of group memberships "A", "B", etc for each node.
If the network is labelled,
then the assignments will be labelled with the nodes' names.
}
\description{
\code{node_in_core()} categorizes nodes into two or more core/periphery
categories based on their coreness.
}
\section{Core-periphery categories}{

This function categorizes nodes based on their coreness into a specified
number of groups. The groups are labeled as "Core", "Semi-core",
"Semi-periphery", and "Periphery" depending on the number of groups
specified.
The categorization can be done using different methods: equal-width bins,
quantile-based bins, or k-means clustering.
}

\examples{
node_in_core(ison_adolescents)
}
\references{
\subsection{On core-periphery categorization}{

Wallerstein, Immanuel. 1974.
"Dependence in an Interdependent World: The Limited Possibilities of Transformation Within the Capitalist World Economy."
\emph{African Studies Review}, 17(1), 1-26.
\doi{https://doi.org/10.2307/523574}
}
}
\seealso{
Other core-periphery:
\code{\link{mark_core}},
\code{\link{measure_core}}

Other memberships:
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{core-periphery}
\concept{memberships}
\concept{nodal}
