% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/motif_census.R
\name{motif_exposure}
\alias{motif_exposure}
\alias{node_x_exposure}
\title{Motifs of nodes exposure}
\usage{
node_x_exposure(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{node_motif} matrix with one row for each node in the network and
a column for each motif type,
giving the count of each motif in which each node participates.
It is printed as a tibble, however, to avoid greedy printing.
If the network is labelled,
then the node names will be in a column named \code{names}.
}
\description{
\code{node_x_exposure()} produces a motif matrix of nodes' exposure to
infection/adoption by time step.
}
\examples{
node_x_exposure(play_diffusion(create_tree(12)))
}
\seealso{
Other diffusion:
\code{\link{mark_diff}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{member_diffusion}},
\code{\link{motif_hazard}}

Other motifs:
\code{\link{motif_brokerage_net}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_hazard}},
\code{\link{motif_hierarchy}},
\code{\link{motif_net}},
\code{\link{motif_node}},
\code{\link{motif_path}},
\code{\link{motif_periods}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{diffusion}
\concept{motifs}
\concept{nodal}
