% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mark_nodes.R
\name{mark_degree}
\alias{mark_degree}
\alias{node_is_isolate}
\alias{node_is_pendant}
\alias{node_is_universal}
\title{Marking nodes based on degree properties}
\usage{
node_is_isolate(.data)

node_is_pendant(.data)

node_is_universal(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{node_mark} logical vector the length of the nodes in the network,
giving either TRUE or FALSE for each node depending on
whether the condition is matched.
}
\description{
These functions return logical vectors the length of the
nodes in a network identifying which hold certain properties or positions in the network.
\itemize{
\item \code{node_is_isolate()} marks nodes that are isolates,
with neither incoming nor outgoing ties.
\item \code{node_is_pendant()} marks nodes that are pendants,
with exactly one incoming or outgoing tie.
\item \code{node_is_universal()} identifies whether nodes are adjacent to all other
nodes in the network.
}
}
\section{Universal/dominating node}{

A universal node is adjacent to all other nodes in the network.
It is also sometimes called the dominating vertex because it represents
a one-element dominating set.
A network with a universal node is called a cone, and its universal node
is called the apex of the cone.
A classic example of a cone is a star graph,
but friendship, wheel, and threshold graphs are also cones.
}

\examples{
node_is_isolate(ison_brandes)
node_is_universal(create_star(11))
}
\seealso{
Other degree:
\code{\link{measure_central_degree}},
\code{\link{measure_centralisation_degree}},
\code{\link{measure_centralities_degree}}

Other marks:
\code{\link{mark_core}},
\code{\link{mark_diff}},
\code{\link{mark_dyads}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{mark_select_tie}},
\code{\link{mark_ties}},
\code{\link{mark_triangles}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{degree}
\concept{marks}
\concept{nodal}
