% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_closure.R
\name{measure_closure}
\alias{measure_closure}
\alias{net_by_reciprocity}
\alias{net_by_transitivity}
\alias{net_by_equivalency}
\alias{net_by_congruency}
\title{Measuring network closure}
\usage{
net_by_reciprocity(.data, method = "default")

net_by_transitivity(.data)

net_by_equivalency(.data)

net_by_congruency(.data, object2)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{method}{For reciprocity, either \code{default} or \code{ratio}.
See \code{?igraph::reciprocity}}

\item{object2}{Optionally, a second (two-mode) matrix, igraph, or tidygraph}
}
\value{
A \code{network_measure} numeric score.
}
\description{
These functions offer methods for summarising the closure in configurations
in one-, two-, and three-mode networks:
\itemize{
\item \code{net_by_reciprocity()} measures reciprocity in a (usually directed) network.
\item \code{net_by_transitivity()} measures transitivity in a network.
\item \code{net_by_equivalency()} measures equivalence or reinforcement
in a (usually two-mode) network.
\item \code{net_by_congruency()} measures congruency across two two-mode networks.
}
}
\details{
For one-mode networks, shallow wrappers of igraph versions exist via
\code{net_reciprocity} and \code{net_transitivity}.

For two-mode networks, \code{net_equivalency} calculates the proportion of three-paths in the network
that are closed by fourth tie to establish a "shared four-cycle" structure.

For three-mode networks, \code{net_congruency} calculates the proportion of three-paths
spanning two two-mode networks that are closed by a fourth tie to establish a
"congruent four-cycle" structure.
}
\section{Equivalency}{

The \code{net_by_equivalency()} function calculates the Robins and Alexander (2004)
clustering coefficient for two-mode networks.
Note that for weighted two-mode networks, the result is divided by the average tie weight.
}

\examples{
net_by_reciprocity(ison_southern_women)
net_by_transitivity(ison_adolescents)
net_by_equivalency(ison_southern_women)
}
\references{
\subsection{On equivalency or four-cycles}{

Robins, Garry L, and Malcolm Alexander. 2004.
Small worlds among interlocking directors: Network structure and distance in bipartite graphs.
\emph{Computational & Mathematical Organization Theory} 10(1): 69–94.
\doi{10.1023/B:CMOT.0000032580.12184.c0}.
}

\subsection{On congruency}{

Knoke, David, Mario Diani, James Hollway, and Dimitris C Christopoulos. 2021.
\emph{Multimodal Political Networks}.
Cambridge University Press. Cambridge University Press.
\doi{10.1017/9781108985000}
}
}
\seealso{
Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}
}
\concept{measures}
