% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mark_ties.R
\name{mark_select_tie}
\alias{mark_select_tie}
\alias{tie_is_random}
\alias{tie_is_max}
\alias{tie_is_min}
\title{Marking ties based on measures}
\usage{
tie_is_random(.data, select = 1)

tie_is_max(tie_measure)

tie_is_min(tie_measure)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{select}{Number of elements to select (as TRUE).}

\item{tie_measure}{An object created by a \code{tie_} measure.}
}
\value{
A \code{tie_mark} logical vector the length of the ties in the network,
giving either TRUE or FALSE for each tie depending on
whether the condition is matched.
}
\description{
These functions return logical vectors the length of the ties in a network:
\itemize{
\item \code{tie_is_random()} marks one or more ties at random.
\item \code{tie_is_max()} and \code{tie_is_min()} are more useful
for converting the results from some tie measure into a mark-class object.
They can be particularly useful for highlighting which tie or ties
are key because they minimise or, more often, maximise some measure.
}
}
\examples{
tie_is_max(tie_by_betweenness(ison_brandes))
tie_is_min(tie_by_betweenness(ison_brandes))
}
\seealso{
Other marks:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_dyads}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{mark_ties}},
\code{\link{mark_triangles}}

Other tie:
\code{\link{mark_dyads}},
\code{\link{mark_ties}},
\code{\link{mark_triangles}},
\code{\link{measure_broker_tie}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}

Other selection:
\code{\link{mark_select_node}}
}
\concept{marks}
\concept{selection}
\concept{tie}
