% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_centrality_degree.R
\name{measure_central_degree}
\alias{measure_central_degree}
\alias{node_by_degree}
\alias{node_by_deg}
\alias{node_by_outdegree}
\alias{node_by_indegree}
\alias{node_by_multidegree}
\alias{node_by_posneg}
\alias{node_by_leverage}
\title{Measuring nodes degree-like centrality}
\usage{
node_by_degree(
  .data,
  normalized = TRUE,
  alpha = 1,
  direction = c("all", "out", "in")
)

node_by_deg(.data, alpha = 0, direction = c("all", "out", "in"))

node_by_outdegree(.data, normalized = TRUE, alpha = 0)

node_by_indegree(.data, normalized = TRUE, alpha = 0)

node_by_multidegree(.data, tie1, tie2)

node_by_posneg(.data)

node_by_leverage(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{normalized}{Logical scalar, whether scores are normalized.
Different denominators may be used depending on the measure,
whether the object is one-mode or two-mode, and other arguments.
By default TRUE.}

\item{alpha}{Numeric scalar, the positive tuning parameter introduced in
Opsahl et al (2010) for trading off between degree and strength centrality measures.
By default, \code{alpha = 0}, which ignores tie weights and the measure is solely based
upon degree (the number of ties).
\code{alpha = 1} ignores the number of ties and provides the sum of the tie weights
as strength centrality.
Values between 0 and 1 reflect different trade-offs in the relative contributions of
degree and strength to the final outcome, with 0.5 as the middle ground.
Values above 1 penalise for the number of ties.
Of two nodes with the same sum of tie weights, the node with fewer ties will obtain
the higher score.
This argument is ignored except in the case of a weighted network.}

\item{direction}{Character string, “out” bases the measure on outgoing ties,
“in” on incoming ties, and "all" on either/the sum of the two.
By default "all".}

\item{tie1}{Character string indicating the first uniplex network.}

\item{tie2}{Character string indicating the second uniplex network.}
}
\value{
A \code{node_measure} numeric vector the length of the nodes in the network,
providing the scores for each node.
If the network is labelled,
then the scores will be labelled with the nodes' names.
}
\description{
These functions calculate common degree-related centrality measures for one- and two-mode networks:
\itemize{
\item \code{node_by_degree()} measures the degree centrality of nodes in an unweighted network,
or weighted degree/strength of nodes in a weighted network;
there are several related shortcut functions:
\itemize{
\item \code{node_by_deg()} returns the unnormalised results.
\item \code{node_by_indegree()} returns the \code{direction = 'in'} results.
\item \code{node_by_outdegree()} returns the \code{direction = 'out'} results.
}
\item \code{node_by_multidegree()} measures the ratio between types of ties in a multiplex network.
\item \code{node_by_posneg()} measures the PN (positive-negative) centrality of a signed network.
\item \code{node_by_leverage()} measures the leverage centrality of nodes in a network.
}

All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. \code{\link[manynet:to_undirected]{manynet::to_undirected()}} functions.
All centrality and centralization measures return normalized measures by default,
including for two-mode networks.
}
\section{Degree centrality}{

The degree of a node is the number of connections it has.
It is also sometimes called the valency of a node, \eqn{d(v)}.
The maximum degree in a network is often denoted \eqn{\Delta (G)} and
the minimum degree in a network \eqn{\delta (G)}.
The total degree of a network is the sum of all degrees, \eqn{\sum_v d(v)}.
The degree sequence is the set of all nodes' degrees,
ordered from largest to smallest.
Directed networks discriminate between
outdegree (degree of outgoing ties) and
indegree (degree of incoming ties).
}

\section{Leverage centrality}{

Leverage centrality concerns the degree of a node compared with that of its
neighbours, \eqn{J}:
\deqn{C_L(i) = \frac{1}{d(i)} \sum_{j \in J(i)} \frac{d(i) - d(j)}{d(i) + d(j)}}
}

\examples{
node_by_degree(ison_southern_women)
}
\references{
\subsection{On multimodal centrality}{

Faust, Katherine. 1997.
"Centrality in affiliation networks."
\emph{Social Networks} 19(2): 157-191.
\doi{10.1016/S0378-8733(96)00300-0}

Borgatti, Stephen P., and Martin G. Everett. 1997.
"Network analysis of 2-mode data."
\emph{Social Networks} 19(3): 243-270.
\doi{10.1016/S0378-8733(96)00301-2}

Borgatti, Stephen P., and Daniel S. Halgin. 2011.
"Analyzing affiliation networks."
In \emph{The SAGE Handbook of Social Network Analysis},
edited by John Scott and Peter J. Carrington, 417–33.
London, UK: Sage.
\doi{10.4135/9781446294413.n28}
}

\subsection{On strength centrality}{

Opsahl, Tore, Filip Agneessens, and John Skvoretz. 2010.
"Node centrality in weighted networks: Generalizing degree and shortest paths."
\emph{Social Networks} 32, 245-251.
\doi{10.1016/j.socnet.2010.03.006}
}

\subsection{On signed centrality}{

Everett, Martin G., and Stephen P. Borgatti. 2014.
“Networks Containing Negative Ties.”
\emph{Social Networks} 38:111–20.
\doi{10.1016/j.socnet.2014.03.005}
}

\subsection{On leverage centrality}{

Joyce, Karen E., Paul J. Laurienti, Jonathan H. Burdette, and Satoru Hayasaka. 2010.
"A New Measure of Centrality for Brain Networks".
\emph{PLoS ONE} 5(8): e12200.
\doi{10.1371/journal.pone.0012200}
}
}
\seealso{
Other degree:
\code{\link{mark_degree}},
\code{\link{measure_centralisation_degree}},
\code{\link{measure_centralities_degree}}

Other centrality:
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralisation_between}},
\code{\link{measure_centralisation_close}},
\code{\link{measure_centralisation_degree}},
\code{\link{measure_centralisation_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}

Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{centrality}
\concept{degree}
\concept{measures}
\concept{nodal}
