% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_diffusion.R
\name{member_diffusion}
\alias{member_diffusion}
\alias{node_in_adopter}
\title{Memberships in a diffusion process}
\usage{
node_in_adopter(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{node_member} character vector the length of the nodes in the network,
of group memberships "A", "B", etc for each node.
If the network is labelled,
then the assignments will be labelled with the nodes' names.
}
\description{
\code{node_in_adopter()} classifies membership of nodes into diffusion categories
by where on the distribution of adopters they fell.
Valente (1995) defines five memberships:
\itemize{
\item \emph{Early adopter}: those with an adoption time less than
the average adoption time minus one standard deviation of adoptions times
\item \emph{Early majority}: those with an adoption time between
the average adoption time and
the average adoption time minus one standard deviation of adoptions times
\item \emph{Late majority}: those with an adoption time between
the average adoption time and
the average adoption time plus one standard deviation of adoptions times
\item \emph{Laggard}: those with an adoption time greater than
the average adoption time plus one standard deviation of adoptions times
\item \emph{Non-adopter}: those without an adoption time,
i.e. never adopted
}
}
\examples{
  smeg <- generate_smallworld(15, 0.025)
  smeg_diff <- play_diffusion(smeg, recovery = 0.2)
  # To classify nodes by their position in the adoption curve
  (adopts <- node_in_adopter(smeg_diff))
  summary(adopts)
}
\references{
\subsection{On adopter classes}{

Valente, Tom W. 1995.
\emph{Network models of the diffusion of innovations}
(2nd ed.). Cresskill N.J.: Hampton Press.
}
}
\seealso{
Other memberships:
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_equivalence}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}

Other diffusion:
\code{\link{mark_diff}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{motif_exposure}},
\code{\link{motif_hazard}}
}
\concept{diffusion}
\concept{memberships}
\concept{nodal}
