% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_holes.R
\name{measure_broker_node}
\alias{measure_broker_node}
\alias{node_by_bridges}
\alias{node_by_redundancy}
\alias{node_by_effsize}
\alias{node_by_efficiency}
\alias{node_by_constraint}
\alias{node_by_hierarchy}
\alias{node_by_neighbours_degree}
\title{Measuring nodes brokerage}
\usage{
node_by_bridges(.data)

node_by_redundancy(.data)

node_by_effsize(.data)

node_by_efficiency(.data)

node_by_constraint(.data)

node_by_hierarchy(.data)

node_by_neighbours_degree(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{node_measure} numeric vector the length of the nodes in the network,
providing the scores for each node.
If the network is labelled,
then the scores will be labelled with the nodes' names.
}
\description{
These function provide different measures of the degree to which nodes
fill structural holes, as outlined in Burt (1992):
\itemize{
\item \code{node_by_bridges()} measures the sum of bridges to which each node
is adjacent.
\item \code{node_by_redundancy()} measures the redundancy of each nodes' contacts.
\item \code{node_by_effsize()} measures nodes' effective size.
\item \code{node_by_efficiency()} measures nodes' efficiency.
\item \code{node_by_constraint()} measures nodes' constraint scores for one-mode networks
according to Burt (1992) and for two-mode networks according to Hollway et al (2020).
\item \code{node_by_hierarchy()} measures nodes' exposure to hierarchy,
where only one or two contacts are the source of closure.
\item \code{node_by_neighbours_degree()} measures nodes' average nearest neighbors degree,
or \eqn{knn}, a measure of the type of local environment a node finds itself in
}

Burt's theory holds that while those nodes embedded in dense clusters
of close connections are likely exposed to the same or similar ideas and information,
those who fill structural holes between two otherwise disconnected groups
can gain some comparative advantage from that position.
}
\details{
A number of different ways of measuring these structural holes are available.
Note that we use Borgatti's reformulation for unweighted networks in
\code{node_redundancy()} and \code{node_effsize()}.
Redundancy is thus \eqn{\frac{2t}{n}},
where \eqn{t} is the sum of ties and \eqn{n} the sum of nodes in each node's neighbourhood,
and effective size is calculated as \eqn{n - \frac{2t}{n}}.
Node efficiency is the node's effective size divided by its degree.
}
\examples{
node_by_bridges(ison_adolescents)
node_by_bridges(ison_southern_women)
node_by_redundancy(ison_adolescents)
node_by_redundancy(ison_southern_women)
node_by_effsize(ison_adolescents)
node_by_effsize(ison_southern_women)
node_by_efficiency(ison_adolescents)
node_by_efficiency(ison_southern_women)
node_by_constraint(ison_southern_women)
node_by_hierarchy(ison_adolescents)
node_by_hierarchy(ison_southern_women)
}
\references{
\subsection{On structural holes}{

Burt, Ronald S. 1992.
\emph{Structural Holes: The Social Structure of Competition}.
Cambridge, MA: Harvard University Press.
}

Borgatti, Steven. 1997.
“\href{http://www.analytictech.com/connections/v20(1)/holes.htm}{Structural Holes: Unpacking Burt’s Redundancy Measures}”
\emph{Connections} 20(1):35-38.

Burchard, Jake, and Benjamin Cornwell. 2018.
“Structural Holes and Bridging in Two-Mode Networks.”
\emph{Social Networks} 55:11–20.
\doi{10.1016/j.socnet.2018.04.001}

Hollway, James, Jean-Frédéric Morin, and Joost Pauwelyn. 2020.
"Structural conditions for novelty: The introduction of new environmental clauses to the trade regime complex."
\emph{International Environmental Agreements: Politics, Law and Economics} 20 (1): 61–83.
\doi{10.1007/s10784-019-09464-5}

\subsection{On neighbours average degree}{

Barrat, Alain, Marc Barthelemy, Romualdo Pastor-Satorras, and Alessandro Vespignani. 2004.
"The architecture of complex weighted networks",
\emph{Proc. Natl. Acad. Sci.} 101: 3747.
}
}
\seealso{
Other brokerage:
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{member_brokerage}},
\code{\link{motif_brokerage_net}},
\code{\link{motif_brokerage_node}}

Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{brokerage}
\concept{measures}
\concept{nodal}
