% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_hierarchy.R
\name{motif_hierarchy}
\alias{motif_hierarchy}
\alias{net_x_hierarchy}
\title{Motifs of network hierarchy}
\usage{
net_x_hierarchy(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{network_motif} named numeric vector or sometimes a data frame with
one row and a column for each motif type,
giving the count of each motif in the network.
This is printed as a tibble to avoid greedy printing of long vectors.
}
\description{
\code{net_x_hierarchy()} collects the measures of hierarchy into a single motif,
which can be used to compare the relative hierarchy of different networks.
The measures of hierarchy are:
\itemize{
\item \code{net_by_connectedness()} measures the proportion of dyads in the network
that are reachable to one another,
or the degree to which network is a single component.
\item \code{net_by_efficiency()} measures the Krackhardt efficiency score.
\item \code{net_by_upperbound()} measures the Krackhardt (least) upper bound
score.
\item \code{net_by_reciprocity()} measures the proportion of ties in the network that
are reciprocated,
which is a measure of the degree to which the network is non-hierarchical.
}
}
\examples{
net_x_hierarchy(ison_networkers)
}
\references{
\subsection{On hierarchy}{

Krackhardt, David. 1994.
Graph theoretical dimensions of informal organizations.
In Carley and Prietula (eds) \emph{Computational Organizational Theory},
Hillsdale, NJ: Lawrence Erlbaum Associates. Pp. 89-111.

Everett, Martin, and David Krackhardt. 2012.
“A second look at Krackhardt's graph theoretical dimensions of informal organizations.”
\emph{Social Networks}, 34: 159-163.
\doi{10.1016/j.socnet.2011.10.006}
}
}
\seealso{
Other hierarchy:
\code{\link{measure_hierarchy}}

Other motifs:
\code{\link{motif_brokerage_net}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_hazard}},
\code{\link{motif_net}},
\code{\link{motif_node}},
\code{\link{motif_path}},
\code{\link{motif_periods}}
}
\concept{hierarchy}
\concept{motifs}
