% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_cohesion.R
\name{measure_fragmentation}
\alias{measure_fragmentation}
\alias{net_by_cohesion}
\alias{net_by_adhesion}
\alias{net_by_strength}
\alias{net_by_toughness}
\title{Measures of network fragmentation}
\usage{
net_by_cohesion(.data)

net_by_adhesion(.data)

net_by_strength(.data)

net_by_toughness(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{network_measure} numeric score.
}
\description{
These functions return values relating to how connected a network is
and the number of nodes or edges to remove that would increase fragmentation.
\itemize{
\item \code{net_by_cohesion()} measures the minimum number of nodes to remove
from the network needed to increase the number of components.
\item \code{net_by_toughness()} measures the number of nodes that would need to be
removed from a network to increase its number of components.
\item \code{net_by_adhesion()} measures the minimum number of ties to remove
from the network needed to increase the number of components.
\item \code{net_by_strength()} measures the number of ties that would need to be
removed from a network to increase its number of components.
}
}
\examples{
net_by_cohesion(fict_marvel)
net_by_cohesion(to_giant(fict_marvel))
net_by_adhesion(fict_marvel)
net_by_adhesion(to_giant(fict_marvel))
net_by_strength(ison_adolescents)
net_by_toughness(ison_adolescents)
}
\references{
\subsection{On cohesion}{

White, Douglas R and Frank Harary. 2001.
"The Cohesiveness of Blocks In Social Networks: Node Connectivity and Conditional Density."
\emph{Sociological Methodology} 31(1): 305-59.
\doi{10.1111/0081-1750.00098}
}
}
\seealso{
Other cohesion:
\code{\link{mark_triangles}},
\code{\link{measure_breadth}},
\code{\link{measure_cohesion}},
\code{\link{motif_net}},
\code{\link{motif_node}}

Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}
}
\concept{cohesion}
\concept{measures}
