% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/motif_brokerage.R
\name{motif_brokerage_net}
\alias{motif_brokerage_net}
\alias{net_x_brokerage}
\title{Motifs of network brokerage}
\usage{
net_x_brokerage(.data, membership, standardized = FALSE)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{membership}{A character string naming an existing node attribute in
the network, or a categorical vector of the same length as the number of
nodes in the network where each element indicates the group membership of
the corresponding node.
While this may often be a vector created using \verb{node_in_*()} functions,
it can be any character vector that assigns nodes to groups or categories.}

\item{standardized}{Whether the score should be standardized
into a \emph{z}-score indicating how many standard deviations above
or below the average the score lies.}
}
\value{
A \code{network_motif} named numeric vector or sometimes a data frame with
one row and a column for each motif type,
giving the count of each motif in the network.
This is printed as a tibble to avoid greedy printing of long vectors.
}
\description{
\code{net_x_brokerage()} returns the Gould-Fernandez brokerage
roles in a network.
}
\examples{
net_x_brokerage(ison_networkers, "Discipline")
}
\seealso{
Other brokerage:
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{member_brokerage}},
\code{\link{motif_brokerage_node}}

Other motifs:
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_hazard}},
\code{\link{motif_hierarchy}},
\code{\link{motif_net}},
\code{\link{motif_node}},
\code{\link{motif_path}},
\code{\link{motif_periods}}
}
\concept{brokerage}
\concept{motifs}
