% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/motif_brokerage.R
\name{motif_brokerage_node}
\alias{motif_brokerage_node}
\alias{node_x_brokerage}
\title{Motifs of nodes brokerage}
\usage{
node_x_brokerage(.data, membership, standardized = FALSE)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{membership}{A character string naming an existing node attribute in
the network, or a categorical vector of the same length as the number of
nodes in the network where each element indicates the group membership of
the corresponding node.
While this may often be a vector created using \verb{node_in_*()} functions,
it can be any character vector that assigns nodes to groups or categories.}

\item{standardized}{Whether the score should be standardized
into a \emph{z}-score indicating how many standard deviations above
or below the average the score lies.}
}
\value{
A \code{node_motif} matrix with one row for each node in the network and
a column for each motif type,
giving the count of each motif in which each node participates.
It is printed as a tibble, however, to avoid greedy printing.
If the network is labelled,
then the node names will be in a column named \code{names}.
}
\description{
\code{node_x_brokerage()} returns the Gould-Fernandez brokerage
roles played by nodes in a network.
}
\examples{
node_x_brokerage(ison_networkers, "Discipline")
}
\references{
\subsection{On brokerage motifs}{

Gould, Roger V., and Roberto M. Fernandez. 1989.
“Structures of Mediation: A Formal Approach to Brokerage in Transaction Networks.”
\emph{Sociological Methodology}, 19: 89-126.
\doi{10.2307/270949}

Jasny, Lorien, and Mark Lubell. 2015.
“Two-Mode Brokerage in Policy Networks.”
\emph{Social Networks} 41:36–47.
\doi{10.1016/j.socnet.2014.11.005}
}
}
\seealso{
Other brokerage:
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{member_brokerage}},
\code{\link{motif_brokerage_net}}

Other motifs:
\code{\link{motif_brokerage_net}},
\code{\link{motif_exposure}},
\code{\link{motif_hazard}},
\code{\link{motif_hierarchy}},
\code{\link{motif_net}},
\code{\link{motif_node}},
\code{\link{motif_path}},
\code{\link{motif_periods}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{brokerage}
\concept{motifs}
\concept{nodal}
