% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_hierarchy.R
\name{measure_hierarchy}
\alias{measure_hierarchy}
\alias{net_by_connectedness}
\alias{net_by_efficiency}
\alias{net_by_upperbound}
\title{Measures of hierarchy}
\usage{
net_by_connectedness(.data)

net_by_efficiency(.data)

net_by_upperbound(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{network_measure} numeric score.
}
\description{
These functions, together with \code{net_reciprocity()}, are used jointly to
measure how hierarchical a network is:
\itemize{
\item \code{net_by_connectedness()} measures the proportion of dyads in the network
that are reachable to one another,
or the degree to which network is a single component.
\item \code{net_by_efficiency()} measures the Krackhardt efficiency score.
\item \code{net_by_upperbound()} measures the Krackhardt (least) upper bound score.
}
}
\examples{
net_by_connectedness(ison_networkers)
1 - net_by_reciprocity(ison_networkers)
net_by_efficiency(ison_networkers)
net_by_upperbound(ison_networkers)
}
\references{
\subsection{On hierarchy}{

Krackhardt, David. 1994.
Graph theoretical dimensions of informal organizations.
In Carley and Prietula (eds) \emph{Computational Organizational Theory},
Hillsdale, NJ: Lawrence Erlbaum Associates. Pp. 89-111.

Everett, Martin, and David Krackhardt. 2012.
“A second look at Krackhardt's graph theoretical dimensions of informal organizations.”
\emph{Social Networks}, 34: 159-163.
\doi{10.1016/j.socnet.2011.10.006}
}
}
\seealso{
Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_periods}}

Other hierarchy:
\code{\link{motif_hierarchy}}
}
\concept{hierarchy}
\concept{measures}
