% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_centrality_between.R
\name{measure_central_between}
\alias{measure_central_between}
\alias{node_by_betweenness}
\alias{node_by_induced}
\alias{node_by_flow}
\alias{node_by_stress}
\title{Measuring nodes betweenness-like centrality}
\usage{
node_by_betweenness(.data, normalized = TRUE, cutoff = NULL)

node_by_induced(.data, normalized = TRUE, cutoff = NULL)

node_by_flow(.data, normalized = TRUE)

node_by_stress(.data, normalized = TRUE)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{normalized}{Logical scalar, whether scores are normalized.
Different denominators may be used depending on the measure,
whether the object is one-mode or two-mode, and other arguments.
By default TRUE.}

\item{cutoff}{The maximum path length to consider when calculating betweenness.
If negative or NULL (the default), there's no limit to the path lengths considered.}
}
\value{
A \code{node_measure} numeric vector the length of the nodes in the network,
providing the scores for each node.
If the network is labelled,
then the scores will be labelled with the nodes' names.
}
\description{
These functions calculate common betweenness-related centrality measures for one- and two-mode networks:
\itemize{
\item \code{node_by_betweenness()} measures the betweenness centralities of nodes in a network.
\item \code{node_by_induced()} measures the induced betweenness centralities of nodes in a network.
\item \code{node_by_flow()} measures the flow betweenness centralities of nodes in a network,
which uses an electrical current model for information spreading
in contrast to the shortest paths model used by normal betweenness centrality.
\item \code{node_by_stress()} measures the stress centrality of nodes in a network.
\item \code{tie_by_betweenness()} measures the number of shortest paths going through a tie.
}

All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. \code{\link[manynet:to_undirected]{to_undirected()}} functions.
All centrality and centralization measures return normalized measures by default,
including for two-mode networks.
}
\section{Betweenness centrality}{

Betweenness centrality is based on the number of shortest paths between
other nodes that a node lies upon:
\deqn{C_B(i) = \sum_{j,k:j \neq k, j \neq i, k \neq i} \frac{g_{jik}}{g_{jk}}}
}

\section{Induced centrality}{

Induced centrality or vitality centrality concerns the change in
total betweenness centrality between networks with and without a given node:
\deqn{C_I(i) = C_B(G) - C_B(G\ i)}
}

\section{Flow betweenness centrality}{

Flow betweenness centrality concerns the total maximum flow, \eqn{f},
between other nodes \eqn{j,k} in a network \eqn{G} that a given node mediates:
\deqn{C_F(i) = \sum_{j,k:j\neq k, j\neq i, k\neq i} f(j,k,G) - f(j,k,G\ i)}
When normalized (by default) this sum of differences is divided by the
sum of flows \eqn{f(i,j,G)}.
}

\section{Stress centrality}{

Stress centrality is the number of all shortest paths or geodesics, \eqn{g},
between other nodes that a given node mediates:
\deqn{C_S(i) = \sum_{j,k:j \neq k, j \neq i, k \neq i} g_{jik}}
High stress nodes lie on a large number of shortest paths between other
nodes, and thus associated with bridging or spanning boundaries.
}

\examples{
node_by_betweenness(ison_southern_women)
node_by_induced(ison_adolescents)
}
\references{
\subsection{On betweenness centrality}{

Freeman, Linton. 1977.
"A set of measures of centrality based on betweenness".
\emph{Sociometry}, 40(1): 35–41.
\doi{10.2307/3033543}
}

\subsection{On induced centrality}{

Everett, Martin and Steve Borgatti. 2010.
"Induced, endogenous and exogenous centrality"
\emph{Social Networks}, 32: 339-344.
\doi{10.1016/j.socnet.2010.06.004}
}

\subsection{On flow centrality}{

Freeman, Lin, Stephen Borgatti, and Douglas White. 1991.
"Centrality in Valued Graphs: A Measure of Betweenness Based on Network Flow".
\emph{Social Networks}, 13(2), 141-154.

Koschutzki, D., K.A. Lehmann, L. Peeters, S. Richter, D. Tenfelde-Podehl, and O. Zlotowski. 2005.
"Centrality Indices".
In U. Brandes and T. Erlebach (eds.), \emph{Network Analysis: Methodological Foundations}.
Berlin: Springer.
}

\subsection{On stress centrality}{

Shimbel, A. 1953.
"Structural Parameters of Communication Networks".
\emph{Bulletin of Mathematical Biophysics}, 15:501-507.
\doi{10.1007/BF02476438}
}
}
\seealso{
Other betweenness:
\code{\link{measure_centralisation_between}},
\code{\link{measure_centralities_between}}

Other centrality:
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralisation_between}},
\code{\link{measure_centralisation_close}},
\code{\link{measure_centralisation_degree}},
\code{\link{measure_centralisation_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}

Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{betweenness}
\concept{centrality}
\concept{measures}
\concept{nodal}
