% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mark_ties.R
\name{mark_dyads}
\alias{mark_dyads}
\alias{tie_is_multiple}
\alias{tie_is_reciprocated}
\title{Marking ties based on dyadic properties}
\usage{
tie_is_multiple(.data)

tie_is_reciprocated(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{tie_mark} logical vector the length of the ties in the network,
giving either TRUE or FALSE for each tie depending on
whether the condition is matched.
}
\description{
These functions return logical vectors the length of the ties
in a network identifying which are embedded within particular dyads.
\itemize{
\item \code{tie_is_multiple()} marks ties that are multiples.
\item \code{tie_is_reciprocated()} marks ties that are mutual/reciprocated.
}

They are most useful in highlighting parts of the network where
relationships are denser.
}
\examples{
tie_is_multiple(fict_marvel)
tie_is_reciprocated(ison_algebra)
}
\seealso{
Other marks:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{mark_select_tie}},
\code{\link{mark_ties}},
\code{\link{mark_triangles}}

Other tie:
\code{\link{mark_select_tie}},
\code{\link{mark_ties}},
\code{\link{mark_triangles}},
\code{\link{measure_broker_tie}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}
}
\concept{marks}
\concept{tie}
