% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/motif_census.R
\name{motif_node}
\alias{motif_node}
\alias{node_x_dyad}
\alias{node_x_triad}
\alias{node_x_tetrad}
\title{Motifs of nodes cohesion}
\usage{
node_x_dyad(.data)

node_x_triad(.data)

node_x_tetrad(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{node_motif} matrix with one row for each node in the network and
a column for each motif type,
giving the count of each motif in which each node participates.
It is printed as a tibble, however, to avoid greedy printing.
If the network is labelled,
then the node names will be in a column named \code{names}.
}
\description{
These functions include ways to take a census of the positions of nodes
in a network:
\itemize{
\item \code{node_x_tie()} returns a census of the ties in a network.
For directed networks, out-ties and in-ties are bound together.
For multiplex networks, the various types of ties are bound together.
\item \code{node_x_triad()} returns a census of the triad configurations
nodes are embedded in.
\item \code{node_x_tetrad()} returns a census of nodes' positions
in motifs of four nodes.
\item \code{node_x_path()} returns the shortest path lengths
of each node to every other node in the network.
}
}
\section{Tetrad census}{

The nodal tetrad census counts the number of four-node configurations
that each node is embedded in.
The function returns a matrix with a special naming convention:
\itemize{
\item E4 (aka co-K4): This is an empty set of four nodes; no ties
\item I4 (aka co-diamond): This is a set of four nodes with just one tie
\item H4 (aka co-C4): This set of four nodes includes two non-adjacent ties
\item L4 (aka co-paw): This set of four nodes includes two adjacent ties
\item D4 (aka co-claw): This set of four nodes includes three adjacent ties,
in the form of a triangle with one isolate
\item U4 (aka P4, four-actor line): This set of four nodes includes three ties
arranged in a line
\item Y4 (aka claw): This set of four nodes includes three ties all adjacent
to a single node
\item P4 (aka paw, kite): This set of four nodes includes four ties arranged
as a triangle with an extra tie hanging off of one of the nodes
\item C4 (aka bifan): This is a symmetric box or 4-cycle or set of shared choices
\item Z4 (aka diamond): This resembles C4 but with an extra tie cutting across the box
\item X4 (aka K4): This resembles C4 but with two extra ties cutting across the box;
a realisation of all possible ties
}

Graphs of these motifs can be shown using
\code{plot(node_by_tetrad(ison_southern_women))}.
}

\examples{
node_x_dyad(ison_networkers)
task_eg <- to_named(to_uniplex(ison_algebra, "tasks"))
(triad_cen <- node_x_triad(task_eg))
node_x_tetrad(ison_southern_women)
}
\references{
\subsection{On the dyad census}{

Holland, Paul W., and Samuel Leinhardt. 1970.
"A Method for Detecting Structure in Sociometric Data".
\emph{American Journal of Sociology}, 76: 492-513.
\doi{10.1016/B978-0-12-442450-0.50028-6}
}

\subsection{On the triad census}{

Davis, James A., and Samuel Leinhardt. 1967.
“\href{https://files.eric.ed.gov/fulltext/ED024086.pdf}{The Structure of Positive Interpersonal Relations in Small Groups}.” 55.
}

\subsection{On the tetrad census}{

Ortmann, Mark, and Ulrik Brandes. 2017.
“Efficient Orbit-Aware Triad and Quad Census in Directed and Undirected Graphs.”
\emph{Applied Network Science} 2(1):13.
\doi{10.1007/s41109-017-0027-2}.

McMillan, Cassie, and Diane Felmlee. 2020.
"Beyond Dyads and Triads: A Comparison of Tetrads in Twenty Social Networks".
\emph{Social Psychology Quarterly} 83(4): 383-404.
\doi{10.1177/0190272520944151}
}
}
\seealso{
Other cohesion:
\code{\link{mark_triangles}},
\code{\link{measure_breadth}},
\code{\link{measure_cohesion}},
\code{\link{measure_fragmentation}},
\code{\link{motif_net}}

Other motifs:
\code{\link{motif_brokerage_net}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_hazard}},
\code{\link{motif_hierarchy}},
\code{\link{motif_net}},
\code{\link{motif_path}},
\code{\link{motif_periods}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_path}}
}
\concept{cohesion}
\concept{motifs}
\concept{nodal}
