% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_heterogeneity.R
\name{measure_assort_net}
\alias{measure_assort_net}
\alias{net_by_heterophily}
\alias{net_by_homophily}
\alias{net_by_assortativity}
\alias{net_by_spatial}
\title{Measures of network assortativity}
\usage{
net_by_heterophily(.data, attribute)

net_by_homophily(
  .data,
  attribute,
  assortativity = c("ie", "ei", "yule", "geary")
)

net_by_assortativity(.data)

net_by_spatial(.data, attribute)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{attribute}{Name of a nodal attribute, mark, measure, or membership vector.}

\item{assortativity}{Which method to use for \verb{*_homophily()}.
Either "ie" (negative E-I index), "ei" (E-I index),
"yule" (Yule's Q), or "geary" (Geary's C).
Default is "ie".
The E-I index is the number of ties between (or \emph{external}) nodes
grouped in some mutually exclusive categories
minus the number of ties within (or \emph{internal}) these groups
divided by the total number of ties.
This value can range from 1 to -1,
where 1 indicates ties only between categories/groups and -1 ties only within categories/groups.

Yule's Q is a measure of association for two binary variables, calculated as:
\deqn{Q = \frac{ad - bc}{ad + bc}}
where \eqn{a} is the number of ties between nodes in the same category,
\eqn{b} is the number of ties between nodes in different categories,
\eqn{c} is the number of non-ties between nodes in the same category,
and \eqn{d} is the number of non-ties between nodes in different categories.
This value can range from -1 to 1, where 1 indicates perfect association
(all ties are between nodes in the same category), -1 indicates perfect disassociation
(all ties are between nodes in different categories), and 0 indicates no association.

Geary's C is a measure of spatial autocorrelation, calculated as:
\deqn{C = \frac{(n - 1) \sum
\limits_{i=1}^n \sum\limits_{j=1}^n w_{ij} (x_i - x_j)^2}{2W \sum\limits_{i=1}^n (x_i - \bar{x})^2}}
where \eqn{n} is the number of nodes, \eqn{
w_{ij}} is the weight of the tie between nodes \eqn{i} and \eqn{j},
\eqn{x_i} is the attribute value of node \eqn{i},
\eqn{\bar{x}} is the mean attribute value across all nodes, and \eqn{W} is the sum of all tie weights.
This value can range from 0 to 2, where values less than 1
indicate positive autocorrelation (similar values are more likely to be connected),
values greater than 1 indicate negative autocorrelation (dissimilar values are more likely
to be connected), and a value of 1 indicates no autocorrelation.
If an incompatible method is chosen for the attribute type,
a suitable alternative will be used instead with a message.}
}
\value{
A \code{network_measure} numeric score.
}
\description{
These functions offer ways to measure the distribution or assortativity
of ties in a network:
\itemize{
\item \code{net_by_heterophily()} measures how embedded nodes in the network
are within groups of nodes with the same attribute.
\item \code{net_by_homophily()} measures how embedded nodes in the network
are within groups of nodes with the same attribute, but with more options for method.
\item \code{net_by_assortativity()} measures the degree assortativity in a network.
\item \code{net_by_spatial()} measures the spatial association/autocorrelation
(global Moran's I) in a network.
}

Note that for two-mode networks,
homophily is calculated on the mode with the attribute of interest,
and the other mode is ignored.
If the attribute is present on both modes,
homophily is calculated on the first mode by default,
but a message is given and the user can choose to calculate homophily on the
other mode instead by subsetting the attribute vector and
converting the network to a one-mode network.
}
\section{Heterophily}{

Given a partition of a network into a number of mutually exclusive groups then
The E-I index is the number of ties between (or \emph{external}) nodes
grouped in some mutually exclusive categories
minus the number of ties within (or \emph{internal}) these groups
divided by the total number of ties.
This value can range from 1 to -1,
where 1 indicates ties only between categories/groups and -1 ties only within categories/groups.
}

\examples{
marvel_friends <- to_unsigned(to_uniplex(fict_marvel, "relationship"), "positive")
net_by_heterophily(marvel_friends, "Gender")
net_by_heterophily(marvel_friends, "Attractive")
net_by_homophily(marvel_friends, "Gender")
net_by_assortativity(ison_networkers)
net_by_spatial(ison_lawfirm, "age")
}
\references{
\subsection{On heterophily}{

Krackhardt, David, and Robert N. Stern. 1988.
Informal networks and organizational crises: an experimental simulation.
\emph{Social Psychology Quarterly} 51(2): 123-140.
\doi{10.2307/2786835}

McPherson, Miller, Lynn Smith-Lovin, and James M. Cook. 2001.
"Birds of a Feather: Homophily in Social Networks".
\emph{Annual Review of Sociology}, 27(1): 415-444.
\doi{10.1146/annurev.soc.27.1.415}
}

\subsection{On assortativity}{

Newman, Mark E.J. 2002.
"Assortative mixing in networks".
\emph{Physical Review Letters}, 89(20): 208701.
\doi{10.1103/physrevlett.89.208701}
}

\subsection{On spatial autocorrelation}{

Moran, Patrick Alfred Pierce. 1950.
"Notes on continuous stochastic phenomena".
\emph{Biometrika} 37(1): 17-23.
\doi{10.2307/2332142}
}
}
\seealso{
Other diversity:
\code{\link{measure_assort_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}}

Other measures:
\code{\link{measure_assort_node}},
\code{\link{measure_breadth}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}
}
\concept{diversity}
\concept{measures}
