% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_cohesion.R
\name{measure_breadth}
\alias{measure_breadth}
\alias{net_by_diameter}
\alias{net_by_length}
\title{Measures of network breadth}
\usage{
net_by_diameter(.data)

net_by_length(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{network_measure} numeric score.
}
\description{
These functions return values or vectors relating to how broad a network is.
\itemize{
\item \code{net_by_diameter()} measures the maximum path length in the network.
\item \code{net_by_length()} measures the average path length in the network.
}
}
\examples{
net_by_diameter(fict_marvel)
net_by_diameter(to_giant(fict_marvel))
net_by_length(fict_marvel)
net_by_length(to_giant(fict_marvel))
}
\seealso{
Other cohesion:
\code{\link{mark_triangles}},
\code{\link{measure_cohesion}},
\code{\link{measure_fragmentation}},
\code{\link{motif_net}},
\code{\link{motif_node}}

Other measures:
\code{\link{measure_assort_net}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_broker_tie}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}},
\code{\link{measure_closure}},
\code{\link{measure_closure_node}},
\code{\link{measure_cohesion}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_infection}},
\code{\link{measure_diffusion_net}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_net}},
\code{\link{measure_diverse_node}},
\code{\link{measure_features}},
\code{\link{measure_fragmentation}},
\code{\link{measure_hierarchy}},
\code{\link{measure_periods}}
}
\concept{cohesion}
\concept{measures}
