% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mark_ties.R
\name{mark_triangles}
\alias{mark_triangles}
\alias{tie_is_triangular}
\alias{tie_is_transitive}
\alias{tie_is_triplet}
\alias{tie_is_cyclical}
\alias{tie_is_simmelian}
\alias{tie_is_imbalanced}
\title{Marking ties based on triangular properties}
\usage{
tie_is_triangular(.data)

tie_is_transitive(.data)

tie_is_triplet(.data)

tie_is_cyclical(.data)

tie_is_simmelian(.data)

tie_is_imbalanced(.data)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}
}
\value{
A \code{tie_mark} logical vector the length of the ties in the network,
giving either TRUE or FALSE for each tie depending on
whether the condition is matched.
}
\description{
These functions return logical vectors the length of the ties
in a network identifying which hold certain properties or positions in the network.
\itemize{
\item \code{tie_is_triangular()} marks ties that are part of triangles.
\item \code{tie_is_cyclical()} marks ties that are part of cycles.
\item \code{tie_is_triplet()} marks ties that are part of transitive triplets.
\item \code{tie_is_simmelian()} marks ties that are both in a triangle
and fully reciprocated.
\item \code{tie_is_imbalanced()} marks ties that are part of imbalanced triads.
\item \code{tie_is_transitive()} marks ties that complete transitive closure.
}

They are most useful in highlighting parts of the network that
are cohesively connected.
}
\examples{
ison_monks |> to_uniplex("like") |> 
  mutate_ties(tri = tie_is_triangular())
ison_adolescents |> to_directed() |> 
  mutate_ties(trans = tie_is_transitive())
ison_adolescents |> to_directed() |> 
  mutate_ties(trip = tie_is_triplet())
ison_adolescents |> to_directed() |> 
  mutate_ties(cyc = tie_is_cyclical())
ison_monks |> to_uniplex("like") |> 
  mutate_ties(simmel = tie_is_simmelian())
fict_marvel |> to_uniplex("relationship") |> tie_is_imbalanced()
}
\seealso{
Other marks:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_dyads}},
\code{\link{mark_nodes}},
\code{\link{mark_select_node}},
\code{\link{mark_select_tie}},
\code{\link{mark_ties}}

Other tie:
\code{\link{mark_dyads}},
\code{\link{mark_select_tie}},
\code{\link{mark_ties}},
\code{\link{measure_broker_tie}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}

Other cohesion:
\code{\link{measure_breadth}},
\code{\link{measure_cohesion}},
\code{\link{measure_fragmentation}},
\code{\link{motif_net}},
\code{\link{motif_node}}
}
\concept{cohesion}
\concept{marks}
\concept{tie}
