% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/measure_centrality_closeness.R
\name{measure_centralisation_close}
\alias{measure_centralisation_close}
\alias{net_by_closeness}
\alias{mode_by_closeness}
\alias{net_by_reach}
\alias{net_by_harmonic}
\title{Measuring networks closeness-like centralisation}
\usage{
net_by_closeness(.data, normalized = TRUE, direction = c("all", "out", "in"))

mode_by_closeness(.data, normalized = TRUE, direction = c("all", "out", "in"))

net_by_reach(.data, normalized = TRUE, cutoff = 2)

net_by_harmonic(.data, normalized = TRUE, cutoff = 2)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{normalized}{Logical scalar, whether scores are normalized.
Different denominators may be used depending on the measure,
whether the object is one-mode or two-mode, and other arguments.
By default TRUE.}

\item{direction}{Character string, “out” bases the measure on outgoing ties,
“in” on incoming ties, and "all" on either/the sum of the two.
By default "all".}

\item{cutoff}{The maximum path length to consider when calculating betweenness.
If negative or NULL (the default), there's no limit to the path lengths considered.}
}
\value{
\verb{net_by_*()} functions return a \code{network_measure} scalar;
\code{mode_by_closeness()} returns a \code{mode_measure} numeric vector of length two,
giving one centralization score per mode.
}
\description{
\itemize{
\item \code{net_by_closeness()} measures a network's closeness centralization as a
single score.
\item \code{mode_by_closeness()} measures closeness centralization separately for each
mode of a two-mode network, returning one score per mode
(following Borgatti and Everett, 1997).
\item \code{net_by_reach()} measures a network's reach centralization.
\item \code{net_by_harmonic()} measures a network's harmonic centralization.
}

All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. \code{\link[manynet:to_undirected]{to_undirected()}} functions.
All centrality and centralization measures return normalized measures by default,
including for two-mode networks.

For two-mode networks the two modes have different theoretical maxima, so
\code{net_by_closeness()} reports a single network-level score by applying
Freeman's general centralization index over the normalized node closeness
scores, whereas \code{mode_by_closeness()} reports the per-mode scores directly.
}
\examples{
net_by_closeness(ison_southern_women, direction = "in")
mode_by_closeness(ison_southern_women, direction = "in")
}
\references{
Borgatti, Stephen P., and Martin G. Everett. 1997.
"Network analysis of 2-mode data."
\emph{Social Networks} 19(3): 243-269.
\doi{10.1016/S0378-8733(96)00301-2}
}
\seealso{
Other closeness:
\code{\link{measure_central_close}},
\code{\link{measure_centralities_close}}

Other centrality:
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_centralisation_between}},
\code{\link{measure_centralisation_degree}},
\code{\link{measure_centralisation_eigen}},
\code{\link{measure_centralities_between}},
\code{\link{measure_centralities_close}},
\code{\link{measure_centralities_degree}},
\code{\link{measure_centralities_eigen}}
}
\concept{centrality}
\concept{closeness}
