% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mark_nodes.R
\name{mark_nodes}
\alias{mark_nodes}
\alias{node_is_independent}
\alias{node_is_cutpoint}
\alias{node_is_fold}
\alias{node_is_mentor}
\alias{node_is_neighbor}
\title{Marking nodes based on structural properties}
\usage{
node_is_independent(.data)

node_is_cutpoint(.data)

node_is_fold(.data)

node_is_mentor(.data, elites = 0.1)

node_is_neighbor(.data, node)
}
\arguments{
\item{.data}{A network object of class \code{mnet}, \code{igraph}, \code{tbl_graph}, \code{network}, or similar.
For more information on the standard coercion possible,
see \code{\link[manynet:as_tidygraph]{manynet::as_tidygraph()}}.}

\item{elites}{The proportion of nodes to be selected as mentors.
By default this is set at 0.1.
This means that the top 10\% of nodes in terms of degree,
or those equal to the highest rank degree in the network,
whichever is the higher, will be used to select the mentors.

Note that if nodes are equidistant from two mentors,
they will choose one at random.
If a node is without a path to a mentor,
for example because they are an isolate,
a tie to themselves (a loop) will be created instead.
Note that this is a different default behaviour than that
described in Valente and Davis (1999).}

\item{node}{A node ID or name for which neighbors are to be marked.}
}
\value{
A \code{node_mark} logical vector the length of the nodes in the network,
giving either TRUE or FALSE for each node depending on
whether the condition is matched.
}
\description{
These functions return logical vectors the length of the
nodes in a network identifying which hold certain properties or positions in the network.
\itemize{
\item \code{node_is_independent()} marks nodes that are members of the largest independent set,
aka largest internally stable set.
\item \code{node_is_cutpoint()} marks nodes that cut or act as articulation points in a network,
increasing the number of connected components when removed.
\item \code{node_is_fold()} marks nodes that are in a structural fold between two or more
triangles that are only connected by that node.
\item \code{node_is_mentor()} marks a proportion of high indegree nodes as 'mentors' (see details).
\item \code{node_is_neighbor()} marks nodes that are neighbours of a given node.
}
}
\examples{
node_is_independent(ison_adolescents)
node_is_cutpoint(ison_brandes)
node_is_fold(create_explicit(A-B, B-C, A-C, C-D, C-E, D-E))
}
\references{
\subsection{On independent sets}{

Tsukiyama, Shuji, Mikio Ide, Hiromu Ariyoshi, and Isao Shirawaka. 1977.
"A new algorithm for generating all the maximal independent sets".
\emph{SIAM Journal on Computing}, 6(3):505–517.
\doi{10.1137/0206036}
}

\subsection{On articulation or cut-points}{

Tarjan, Robert E. and Uzi Vishkin. 1985.
"An Efficient Parallel Biconnectivity Algorithm",
\emph{SIAM Journal on Computing} 14(4): 862-874.
\doi{10.1137/0214061}
}

\subsection{On structural folds}{

Vedres, Balazs, and David Stark. 2010.
"Structural folds: Generative disruption in overlapping groups",
\emph{American Journal of Sociology} 115(4): 1150-1190.
\doi{10.1086/649497}
}

\subsection{On mentoring}{

Valente, Thomas, and Rebecca Davis. 1999.
"Accelerating the Diffusion of Innovations Using Opinion Leaders",
\emph{Annals of the American Academy of Political and Social Science} 566: 56-67.
}
}
\seealso{
Other marks:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_dyads}},
\code{\link{mark_select_node}},
\code{\link{mark_select_tie}},
\code{\link{mark_ties}},
\code{\link{mark_triangles}}

Other nodal:
\code{\link{mark_core}},
\code{\link{mark_degree}},
\code{\link{mark_diff}},
\code{\link{mark_select_node}},
\code{\link{measure_assort_node}},
\code{\link{measure_broker_node}},
\code{\link{measure_brokerage}},
\code{\link{measure_central_between}},
\code{\link{measure_central_close}},
\code{\link{measure_central_degree}},
\code{\link{measure_central_eigen}},
\code{\link{measure_closure_node}},
\code{\link{measure_core}},
\code{\link{measure_diffusion_node}},
\code{\link{measure_diverse_node}},
\code{\link{member_brokerage}},
\code{\link{member_cliques}},
\code{\link{member_community}},
\code{\link{member_community_hier}},
\code{\link{member_community_non}},
\code{\link{member_components}},
\code{\link{member_core}},
\code{\link{member_diffusion}},
\code{\link{member_equivalence}},
\code{\link{motif_brokerage_node}},
\code{\link{motif_exposure}},
\code{\link{motif_node}},
\code{\link{motif_path}}
}
\concept{marks}
\concept{nodal}
